Function foundationdb::api::get_max_api_version
source · [−]pub fn get_max_api_version() -> i32Expand description
Returns the max api version of the underlying Fdb C API Client
pub fn get_max_api_version() -> i32Returns the max api version of the underlying Fdb C API Client