pub struct NetworkRunner { /* private fields */ }
A foundationDB network event loop runner

Most of the time you should never need to use this directly and use boot().

Implementations

Start the foundationDB network event loop in the current thread.

Safety

This method is unsafe because you MUST call the stop method on the associated NetworkStop before the program exit.

This will only returns once the stop method on the associated NetworkStop object is called or if the foundationDB event loop return an error.