pub struct TransactionCommitError { /* private fields */ }Expand description
A failed to commit transaction.
Implementations
Sourceimpl TransactionCommitError
impl TransactionCommitError
Sourcepub fn on_error(self) -> impl Future<Output = FdbResult<Transaction>>
pub fn on_error(self) -> impl Future<Output = FdbResult<Transaction>>
Implements the recommended retry and backoff behavior for a transaction. This function knows
which of the error codes generated by other Transaction functions represent temporary
error conditions and which represent application errors that should be handled by the
application. It also implements an exponential backoff strategy to avoid swamping the
database cluster with excessive retries when there is a high level of conflict between
transactions.
You should not call this method most of the times and use Database::transact which
implements a retry loop strategy for you.
Sourcepub fn reset(self) -> Transaction
pub fn reset(self) -> Transaction
Reset the transaction to its initial state.
This is similar to dropping the transaction and creating a new one.